.BIEN_sql is an internal function used to submit SQL queries.
.BIEN_sql(
query,
view_full_occurrence_individual = NULL,
agg_traits = NULL,
species_by_political_division = NULL,
bien_species_all = NULL,
ranges = NULL,
bien_taxonomy = NULL,
phylogeny = NULL,
bien_metadata = NULL,
plot_metadata = NULL,
analytical_stem = NULL,
datasource = NULL,
centroid = NULL,
limit = NULL,
return.query = FALSE,
schema = NULL,
print.query = FALSE,
fetch.query = TRUE
)A dataframe returned by the query.
A PostgreSQL query.
Alternative value to be substituted for "view_full_occurrence_individual" in queries when not NULL.
Alternative value to be substituted for "agg_traits" in queries when not NULL.
Alternative value to be substituted for "species_by_political_division" in queries when not NULL.
Alternative value to be substituted for "bien_species_all" in queries when not NULL.
Alternative value to be substituted for "ranges" in queries when not NULL.
Alternative value to be substituted for "bien_taxonomy" in queries when not NULL.
Alternative value to be substituted for "phylogeny" in queries when not NULL.
Alternative value to be substituted for "bien_metadata" in queries when not NULL.
Alternative value to be substituted for "plot_metadata" in queries when not NULL.
Alternative value to be substituted for "analytical_stem" in queries when not NULL.
Alternative value to be substituted for "datasource" in queries when not NULL.
Alternative value to be substituted for "centroid" in queries when not NULL.
A limit on the number of records to be returned. Should be a single number or NULL (the default).
Should the query used be returned rather than executed? Default is FALSE
An alternative schema to be accessed. Used for testing purposes.
Should the query used be printed? Default is FALSE
If TRUE (the default) query is executed using dbFetch. If FALSE, dbGetQuery is used.
if (FALSE) {
.BIEN_sql("SELECT DISTINCT country, scrubbed_species_binomial FROM view_full_occurrence_individual
WHERE country in ( 'United States' );")}
Run the code above in your browser using DataLab