Learn R Programming

BIEN (version 1.2.7)

BIEN_list_country: Extract species list by country

Description

BIEN_list_country downloads a list of all species within a country or countries from the BIEN database.

Usage

BIEN_list_country(
  country = NULL,
  country.code = NULL,
  cultivated = FALSE,
  new.world = NULL,
  ...
)

Value

Dataframe containing species list(s) for the specified country or countries.

Arguments

country

A single country or a vector of countries.

country.code

A single country code or a vector of country codes equal in length to the vector of states/province codes.

cultivated

Return information on cultivation status? Default is FALSE.

new.world

NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.

...

Additional arguments passed to internal functions.

See Also

Other list functions: BIEN_list_all(), BIEN_list_county(), BIEN_list_sf(), BIEN_list_state()

Examples

Run this code
if (FALSE) {
BIEN_list_country("Canada")
country_vector<-c("Canada","United States")
BIEN_list_country(country_vector)}

Run the code above in your browser using DataLab