Learn R Programming

BIEN (version 1.2.7)

BIEN_list_county: Extract a species list by county.

Description

BIEN_list_county produces a list of all species with geovalidated occurrences falling within specified county or counties.

Usage

BIEN_list_county(
  country = NULL,
  state = NULL,
  county = NULL,
  country.code = NULL,
  state.code = NULL,
  county.code = NULL,
  cultivated = FALSE,
  new.world = NULL,
  ...
)

Value

Dataframe containing species list(s) for the specified states/provinces.

Arguments

country

A single country or vector of countries

state

A state or vector of states (or other primary political divisions, e.g. provinces).

county

A single county (or other secondary administrative boundary)or vector of counties.

country.code

A single country (or other primary administrative boundary) code or a vector of country codes equal in length to the vector of states/province codes.

state.code

A single state/province code, or a vector of states/province codes.

county.code

A single county (or other secondary administrative boundary) code or a vector of county codes equal in length to the vectors of states/province codes and country codes.

cultivated

Return information on cultivation status? Default is FALSE.

new.world

NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.

...

Additional arguments passed to internal functions.

See Also

Other list functions: BIEN_list_all(), BIEN_list_country(), BIEN_list_sf(), BIEN_list_state()

Examples

Run this code
if (FALSE) {
BIEN_list_county("United States", "Michigan", "Kent")
BIEN_list_county(country = "United States", state = "Michigan", county = "Kent")
county_vector<-c("Kent","Kalamazoo")
BIEN_list_county(country = "United States", state = "Michigan", county = county_vector)}

Run the code above in your browser using DataLab