Learn R Programming

BIEN (version 1.2.7)

BIEN_list_sf: Extract a list of species within a given sf polygon.

Description

BIEN_list_sf produces a list of all species with occurrence records falling within a user-supplied sf object.

Usage

BIEN_list_sf(sf, cultivated = FALSE, new.world = NULL, ...)

Value

Dataframe containing a list of all species with occurrences in the supplied sf object.

Arguments

sf

An object of class ff. Note that the object must be in WGS84.

cultivated

Return information on cultivation status? Default is FALSE.

new.world

NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.

...

Additional arguments passed to internal functions.

See Also

Other list functions: BIEN_list_all(), BIEN_list_country(), BIEN_list_county(), BIEN_list_state()

Examples

Run this code
if (FALSE) {
library(sf)

BIEN_ranges_species("Carnegiea gigantea") # saves ranges to the current working directory

sf <- st_read(dsn = ".",
              layer = "Carnegiea_gigantea")

species_list <- BIEN_list_sf(sf = sf)
}

Run the code above in your browser using DataLab