BIEN_metadata_citation guides a user through the proper documentation for data downloaded from the BIEN database.
BIEN_metadata_citation(
dataframe = NULL,
trait.dataframe = NULL,
trait.mean.dataframe = NULL,
bibtex_file = NULL,
acknowledgement_file = NULL,
...
)A list object containing information needed for data attribution. Full information for herbaria is available at http://sweetgum.nybg.org/science/ih/
A data.frame of occurrence data downloaded from the BIEN R package.
A data.frame of trait data downloaded from the BIEN R package.
A data.frame of species mean trait data from the function BIEN_trait_mean.
Output file for writing bibtex citations.
Output file for writing acknowledgements.
Additional arguments passed to internal functions.
Other metadata functions:
BIEN_metadata_data_dictionaries(),
BIEN_metadata_database_version(),
BIEN_metadata_list_political_names(),
BIEN_metadata_match_data(),
BIEN_plot_metadata(),
BIEN_ranges_list()