BIEN_metadata_data_dictionaries: Download data dictionaries
Description
BIEN_metadata_data_dictionaries downloads the data dictionaries for the BIEN database.
Usage
BIEN_metadata_data_dictionaries(...)
Value
A list containing data.frames containing different data dictionaries.
"Tables" contains information on the contents of tables.
"Columns" contains information on the contents of columns within tables.
"Values" contains information on some of the values that are used to populated columns, particularly where these may be unclear.
"rbien" contains information on some of the values returned by the BIEN R package.
Arguments
...
Additional arguments passed to internal functions.
See Also
Other metadata functions:
BIEN_metadata_citation(),
BIEN_metadata_database_version(),
BIEN_metadata_list_political_names(),
BIEN_metadata_match_data(),
BIEN_plot_metadata(),
BIEN_ranges_list()