BIEN_occurrence_box extracts occurrences records falling within the specific area.
BIEN_occurrence_box(
min.lat,
max.lat,
min.long,
max.long,
species = NULL,
genus = NULL,
cultivated = FALSE,
new.world = NULL,
all.taxonomy = FALSE,
native.status = FALSE,
natives.only = TRUE,
observation.type = FALSE,
political.boundaries = TRUE,
collection.info = FALSE,
...
)Dataframe containing occurrence records for the specified area.
Minimum latitude
Maximum latitude
Minimum longitude
Maximum longitude
Optional. A single species or a vector of species.
Optional. A single genus or a vector of genera.
Return known cultivated records as well? Default is FALSE.
NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.
Return all taxonomic information? This includes the raw data as well as the "scrubbed" data.
Return information on introduction status? The default value is FALSE. A value of TRUE also returns additional information on introduction status.
Exclude detected introduced species? Default is TRUE.
Return information on type of observation (i.e. specimen vs. plot)? The default value is FALSE.
Return information on political boundaries for an observation? The default value is FALSE.
Return additional information about collection and identification? The default value is FALSE.
Additional arguments passed to internal functions.
Other occurrence functions:
BIEN_occurrence_country(),
BIEN_occurrence_county(),
BIEN_occurrence_family(),
BIEN_occurrence_genus(),
BIEN_occurrence_records_per_species(),
BIEN_occurrence_sf(),
BIEN_occurrence_species(),
BIEN_occurrence_state()
if (FALSE) {
output_test<-
BIEN_occurrence_box(min.lat = 32,max.lat = 33,min.long = -114,max.long = -113,
cultivated = TRUE, new.world = FALSE)}
Run the code above in your browser using DataLab