BIEN_occurrence_family extracts all occurrences for a given family (or families) from the BIEN database.
BIEN_occurrence_family(
family,
cultivated = FALSE,
new.world = NULL,
observation.type = FALSE,
all.taxonomy = FALSE,
native.status = FALSE,
natives.only = TRUE,
political.boundaries = FALSE,
collection.info = FALSE,
only.geovalid = TRUE,
...
)Dataframe containing occurrence records for the specified family/families.
A single family or a vector of families.
Return known cultivated records as well? Default is FALSE.
NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.
Return information on type of observation (i.e. specimen vs. plot)? The default value is FALSE.
Return all taxonomic information? This includes the raw data as well as the "scrubbed" data.
Return information on introduction status? The default value is FALSE. A value of TRUE also returns additional information on introduction status.
Exclude detected introduced species? Default is TRUE.
Return information on political boundaries for an observation? The default value is FALSE.
Return additional information about collection and identification? The default value is FALSE.
Should the returned records be limited to those with validated coordinates? Default is TRUE
Additional arguments passed to internal functions.
Other occurrence functions:
BIEN_occurrence_box(),
BIEN_occurrence_country(),
BIEN_occurrence_county(),
BIEN_occurrence_genus(),
BIEN_occurrence_records_per_species(),
BIEN_occurrence_sf(),
BIEN_occurrence_species(),
BIEN_occurrence_state()
if (FALSE) {
BIEN_occurrence_family("Theaceae")
family_vector<-c("Theaceae","Ericaceae")
BIEN_occurrence_family(family_vector)}
Run the code above in your browser using DataLab