Learn R Programming

BIEN (version 1.2.6)

BIEN_occurrence_sf: Extract occurrence data for specified sf polygon

Description

BIEN_occurrence_sf downloads occurrence records falling within a user-specified sf polygon

Usage

BIEN_occurrence_sf(
  sf,
  cultivated = FALSE,
  new.world = NULL,
  all.taxonomy = FALSE,
  native.status = FALSE,
  natives.only = TRUE,
  observation.type = FALSE,
  political.boundaries = FALSE,
  collection.info = FALSE,
  ...
)

Value

Dataframe containing occurrence records falling within the polygon.

Arguments

sf

An object of class sf. Note that the projection must be WGS84.

cultivated

Return known cultivated records as well? Default is FALSE.

new.world

NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.

all.taxonomy

Return all taxonomic information? This includes the raw data as well as the "scrubbed" data.

native.status

Return information on introduction status? The default value is FALSE. A value of TRUE also returns additional information on introduction status.

natives.only

Exclude detected introduced species? Default is TRUE.

observation.type

Return information on type of observation (i.e. specimen vs. plot)? The default value is FALSE.

political.boundaries

Return information on political boundaries for an observation? The default value is FALSE.

collection.info

Return additional information about collection and identification? The default value is FALSE.

...

Additional arguments passed to internal functions.

See Also

Other occurrence functions: BIEN_occurrence_box(), BIEN_occurrence_country(), BIEN_occurrence_county(), BIEN_occurrence_family(), BIEN_occurrence_genus(), BIEN_occurrence_records_per_species(), BIEN_occurrence_species(), BIEN_occurrence_state()

Examples

Run this code
if (FALSE) {
library(sf)  

# first, we download an example shapefile to use (a species range)

BIEN_ranges_species("Carnegiea gigantea")#saves range to the current working directory

# load the range map as an sf object

sf <- st_read(dsn = ".",layer = "Carnegiea_gigantea")

# get the occurrences that occur within the polygon.

species_occurrences <- BIEN_occurrence_sf(sf = sf)
}

Run the code above in your browser using DataLab