Learn R Programming

BIEN (version 1.2.7)

BIEN_phylogeny_complete: Download the complete BIEN phylogenies

Description

BIEN_phylogeny_complete downloads a specified number of the BIEN phylogeny replicates.

Usage

BIEN_phylogeny_complete(n_phylogenies = 1, seed = NULL, replicates = NULL, ...)

Value

A phylo or multiphylo object containing the specified phylogenies

Arguments

n_phylogenies

The number of phylogenies to download. Should be an integer between 1 and 100. Default is 1.

seed

Argument passed to set.seed. Useful for replicating work with random phylogeny sets.

replicates

The specific replicated phylogenies to return. Should be a numeric vector of integers between 1 and 100.

...

Additional arguments passed to internal functions.

See Also

Other phylogeny functions: BIEN_phylogeny_conservative(), BIEN_phylogeny_label_nodes()

Examples

Run this code
if (FALSE) {
phylos<-BIEN_phylogeny_complete(n_phylogenies = 10,seed = 1)
phylos<-BIEN_phylogeny_complete(replicates = c(1,2,99,100))}

Run the code above in your browser using DataLab