powered by
BIEN_ranges_box extracts range maps for a specified bounding box.
BIEN_ranges_box( min.lat, max.lat, min.long, max.long, directory = NULL, species.names.only = FALSE, return.species.list = TRUE, crop.ranges = FALSE, include.gid = FALSE, ... )
Range maps for all available species within the specified bounding box.
Minimum latitude of the ranges included.
Maximum latitude of the ranges included.
Minimum longitude of the ranges included.
Maximum longitude of the ranges included.
Directory that range maps should be saved in. If none is specified, range maps will be saved in the current working directory.
Return species names rather than spatial data? Default is FALSE.
Should a species list be returned in addition to downloading range maps? Default is FALSE
Should the ranges be cropped to the focal area? Default is FALSE.
Should the files returned have a unique GID appended to them? This is needed if downloading multiple maps for the same species.
Additional arguments passed to internal functions.
Other range functions: BIEN_ranges_genus(), BIEN_ranges_intersect_species(), BIEN_ranges_list(), BIEN_ranges_load_species(), BIEN_ranges_sf(), BIEN_ranges_shapefile_to_skinny(), BIEN_ranges_skinny_ranges_to_richness_raster(), BIEN_ranges_species_bulk(), BIEN_ranges_species()
BIEN_ranges_genus()
BIEN_ranges_intersect_species()
BIEN_ranges_list()
BIEN_ranges_load_species()
BIEN_ranges_sf()
BIEN_ranges_shapefile_to_skinny()
BIEN_ranges_skinny_ranges_to_richness_raster()
BIEN_ranges_species_bulk()
BIEN_ranges_species()
if (FALSE) { temp_dir <- file.path(tempdir(), "BIEN_temp") #Set a working directory BIEN_ranges_box(42,43,-85,-84,species.names.only = TRUE) BIEN_ranges_box(42,43,-85,-84,directory = temp_dir)}
Run the code above in your browser using DataLab