Learn R Programming

BIEN (version 1.2.6)

BIEN_ranges_intersect_species: Download range maps that intersect the range of a given species.

Description

BIEN_ranges_intersect_species extracts range maps for a specified bounding box.

Usage

BIEN_ranges_intersect_species(
  species,
  directory = NULL,
  species.names.only = FALSE,
  include.focal = TRUE,
  return.species.list = TRUE,
  include.gid = FALSE,
  ...
)

Value

Range maps for all available species that intersect the range of the focal species.

Arguments

species

Focal species (or a vector of species) for which to extract intersecting ranges.

directory

Directory that range maps should be saved in. If none is specified, range maps will be saved in the current working directory.

species.names.only

Return species names rather than spatial data? Default is FALSE.

include.focal

Should a range for the focal species be downloaded? Default is TRUE.

return.species.list

Should a species list be returned in addition to downloading range maps? Default is FALSE

include.gid

Should the files returned have a unique GID appended to them? This is needed if downloading multiple maps for the same species.

...

Additional arguments passed to internal functions.

See Also

Other range functions: BIEN_ranges_box(), BIEN_ranges_genus(), BIEN_ranges_list(), BIEN_ranges_load_species(), BIEN_ranges_sf(), BIEN_ranges_shapefile_to_skinny(), BIEN_ranges_skinny_ranges_to_richness_raster(), BIEN_ranges_species_bulk(), BIEN_ranges_species()

Examples

Run this code
if (FALSE) {
temp_dir <- file.path(tempdir(), "BIEN_temp") #Set a working directory
BIEN_ranges_intersect_species(species = "Carnegiea_gigantea",
directory = temp_dir,include.focal = TRUE)
species_vector<-c("Carnegiea_gigantea","Echinocereus coccineus")
BIEN_ranges_intersect_species(species = species_vector,species.names.only = TRUE)
}

Run the code above in your browser using DataLab