if (FALSE) {
# Here we use a range map as our example polygon
BIEN_ranges_species("Carnegiea gigantea") #saves ranges to the current working directory
# Read in the polygon with sf
sf <- sf::st_read(dsn = ".",
layer = "Carnegiea_gigantea")
BIEN_ranges_sf(sf = sf,
limit = 10)
# We use the limit argument to return only 10 range maps.
# Omit the limit argument to get all ranges
#Note that this will save many shapefiles to the working directory.
}
Run the code above in your browser using DataLab