Learn R Programming

BIEN (version 1.2.7)

BIEN_stem_species: Extract stem data for specified species from BIEN

Description

BIEN_stem_species downloads occurrence records for specific species from the BIEN database.

Usage

BIEN_stem_species(
  species,
  cultivated = FALSE,
  new.world = NULL,
  all.taxonomy = FALSE,
  native.status = FALSE,
  natives.only = TRUE,
  political.boundaries = FALSE,
  collection.info = FALSE,
  all.metadata = FALSE,
  ...
)

Value

Dataframe containing stem data for the specified species.

Arguments

species

A single species, or a vector of species. Genus and species should be separated by a space. Genus should be capitalized.

cultivated

Return known cultivated records as well? Default is FALSE.

new.world

NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.

all.taxonomy

Return all taxonomic information? This includes the raw data as well as the "scrubbed" data.

native.status

Return information on introduction status? The default value is FALSE. A value of TRUE also returns additional information on introduction status.

natives.only

Exclude detected introduced species? Default is TRUE.

political.boundaries

Return information on political boundaries for an observation? The default value is FALSE.

collection.info

Return additional information about collection and identification? The default value is FALSE.

all.metadata

Should additional plot metadata be returned? Default is FALSE.

...

Additional arguments passed to internal functions.

See Also

Other stem functions: BIEN_stem_datasource(), BIEN_stem_family(), BIEN_stem_genus(), BIEN_stem_sampling_protocol()

Examples

Run this code
if (FALSE) {
BIEN_stem_species("Abies amabilis")
species_vector<-c("Abies amabilis", "Acer nigrum")
BIEN_stem_species(species_vector)
BIEN_stem_species(species_vector,all.taxonomy = TRUE)}

Run the code above in your browser using DataLab