Learn R Programming

BIEN (version 1.2.6)

BIEN_trait_species: Download trait data for given species.

Description

BIEN_trait_species extracts trait data for the species specified.

Usage

BIEN_trait_species(
  species,
  all.taxonomy = FALSE,
  political.boundaries = FALSE,
  source.citation = FALSE,
  ...
)

Value

A dataframe of all available trait data for the given species.

Arguments

species

A single species or a vector of species.

all.taxonomy

Should full taxonomic information and TNRS output be returned? Default is FALSE.

political.boundaries

Should political boundary information (country, state, etc.) be returned? Default is FALSE.

source.citation

Should readable source information be downloaded for each record? Note that BIEN_metadata_citation may be more useful.

...

Additional arguments passed to internal functions.

See Also

Other trait functions: BIEN_trait_country(), BIEN_trait_family(), BIEN_trait_genus(), BIEN_trait_list(), BIEN_trait_mean(), BIEN_trait_traitbyfamily(), BIEN_trait_traitbygenus(), BIEN_trait_traitbyspecies(), BIEN_trait_traits_per_species(), BIEN_trait_trait()

Examples

Run this code
if (FALSE) {
BIEN_trait_species("Poa annua")
species_vector<-c("Poa annua","Juncus trifidus")
BIEN_trait_species(species_vector)}

Run the code above in your browser using DataLab