Learn R Programming

BIEN (version 1.2.7)

BIEN_trait_trait: Download all measurements of a specific trait(s).

Description

BIEN_trait_trait downloads all measurements of the trait(s) specified.

Usage

BIEN_trait_trait(
  trait,
  all.taxonomy = FALSE,
  political.boundaries = FALSE,
  source.citation = FALSE,
  ...
)

Value

A dataframe of all available trait data for the given trait(s).

Arguments

trait

A single trait or a vector of traits.

all.taxonomy

Should full taxonomic information and TNRS output be returned? Default is FALSE.

political.boundaries

Should political boundary information (country, state, etc.) be returned? Default is FALSE.

source.citation

Should readable source information be downloaded for each record? Note that BIEN_metadata_citation may be more useful.

...

Additional arguments passed to internal functions.

See Also

Other trait functions: BIEN_trait_country(), BIEN_trait_family(), BIEN_trait_genus(), BIEN_trait_list(), BIEN_trait_mean(), BIEN_trait_species(), BIEN_trait_traitbyfamily(), BIEN_trait_traitbygenus(), BIEN_trait_traitbyspecies(), BIEN_trait_traits_per_species()

Examples

Run this code
if (FALSE) {
BIEN_trait_trait("whole plant height")
trait_vector<-c("whole plant height", "leaf dry mass per leaf fresh mass")
BIEN_trait_trait(trait_vector)}

Run the code above in your browser using DataLab