Learn R Programming

BIEN (version 1.2.7)

BIEN_trait_traitbyspecies: Download trait data for given species and trait.

Description

BIEN_trait_traitbyspecies extracts entries that contain the specified species and trait(s).

Usage

BIEN_trait_traitbyspecies(
  species,
  trait,
  all.taxonomy = FALSE,
  political.boundaries = FALSE,
  source.citation = FALSE,
  ...
)

Value

A dataframe of all data matching the specified trait(s) and species.

Arguments

species

A single species or a vector of species.

trait

A single trait or a vector of traits.

all.taxonomy

Should full taxonomic information and TNRS output be returned? Default is FALSE.

political.boundaries

Should political boundary information (country, state, etc.) be returned? Default is FALSE.

source.citation

Should readable source information be downloaded for each record? Note that BIEN_metadata_citation may be more useful.

...

Additional arguments passed to internal functions.

See Also

Other trait functions: BIEN_trait_country(), BIEN_trait_family(), BIEN_trait_genus(), BIEN_trait_list(), BIEN_trait_mean(), BIEN_trait_species(), BIEN_trait_trait(), BIEN_trait_traitbyfamily(), BIEN_trait_traitbygenus(), BIEN_trait_traits_per_species()

Examples

Run this code
if (FALSE) {
BIEN_trait_traitbyspecies(trait = "whole plant height", species = "Carex capitata")
trait_vector<-c("whole plant height", "leaf area")
species_vector<-c("Carex capitata","Betula nana")
BIEN_trait_traitbyspecies(trait=trait_vector,species=species_vector)}

Run the code above in your browser using DataLab