powered by
BIEN_list_country downloads a list of all species within a country or countries from the BIEN database.
BIEN_list_country( country = NULL, country.code = NULL, cultivated = FALSE, new.world = NULL, ... )
Dataframe containing species list(s) for the specified country or countries.
A single country or a vector of countries.
A single country code or a vector of country codes equal in length to the vector of states/province codes.
Return information on cultivation status? Default is FALSE.
NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.
Additional arguments passed to internal functions.
Other list functions: BIEN_list_all(), BIEN_list_county(), BIEN_list_sf(), BIEN_list_state()
BIEN_list_all()
BIEN_list_county()
BIEN_list_sf()
BIEN_list_state()
if (FALSE) { BIEN_list_country("Canada") country_vector<-c("Canada","United States") BIEN_list_country(country_vector)}
Run the code above in your browser using DataLab