powered by
BIEN_list_state produces a list of all species with geovalidated occurrences falling within specified state(s) or province(s).
BIEN_list_state( country = NULL, country.code = NULL, state = NULL, state.code = NULL, cultivated = FALSE, new.world = NULL, ... )
Dataframe containing species list(s) for the specified states/provinces.
A single country or a vector of countries equal in length to the vector of states/provinces.
A single country code or a vector of country codes equal in length to the vector of states/province codes.
A state or vector of states (or other primary political divisions, e.g. provinces).
A single state/province code, or a vector of states/province codes.
Return information on cultivation status? Default is FALSE.
NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.
Additional arguments passed to internal functions.
Other list functions: BIEN_list_all(), BIEN_list_country(), BIEN_list_county(), BIEN_list_sf()
BIEN_list_all()
BIEN_list_country()
BIEN_list_county()
BIEN_list_sf()
if (FALSE) { BIEN_list_state("United States","Michigan") state_vector<-c("Michigan","Arizona") BIEN_list_state(country="United States", state= state_vector)}
Run the code above in your browser using DataLab