- country
A single country or vector of countries.
- state
A state or vector of states (or other primary political divisions, e.g. provinces).
- county
A single county or a vector of counties (or other secondary political division, e.g. parish).
- country.code
A single country (or other primary administrative boundary) code or a vector of country codes equal in length to the vector of states/province codes.
- state.code
A single state/province code, or a vector of states/province codes.
- county.code
A single county (or other secondary administrative boundary) code or a vector of county codes equal in length to the vectors of states/province codes and country codes.
- cultivated
Return known cultivated records as well? Default is FALSE.
- new.world
NULL (The default) returns global records, TRUE returns only New World, and FALSE only Old World.
- all.taxonomy
Return all taxonomic information? This includes the raw data as well as the "scrubbed" data.
- native.status
Return information on introduction status? The default value is FALSE. A value of TRUE also returns additional information on introduction status.
- natives.only
Exclude detected introduced species? Default is TRUE.
- observation.type
Return information on type of observation (i.e. specimen vs. plot)? The default value is FALSE.
- political.boundaries
Return information on political boundaries for an observation? The default value is FALSE.
- collection.info
Return additional information about collection and identification? The default value is FALSE.
- ...
Additional arguments passed to internal functions.