powered by
BIEN_occurrence_records_per_species downloads a count of the number of geovalidated occurrence records for each species in the BIEN database.
BIEN_occurrence_records_per_species(species = NULL, ...)
A dataframe listing the number of geovalidated occurrence records for each species in the BIEN database.
A single species, or vector of species. If NULL, the default, it will return counts for all species.
Additional arguments passed to internal functions.
Other occurrence functions: BIEN_occurrence_box(), BIEN_occurrence_country(), BIEN_occurrence_county(), BIEN_occurrence_family(), BIEN_occurrence_genus(), BIEN_occurrence_sf(), BIEN_occurrence_species(), BIEN_occurrence_state()
BIEN_occurrence_box()
BIEN_occurrence_country()
BIEN_occurrence_county()
BIEN_occurrence_family()
BIEN_occurrence_genus()
BIEN_occurrence_sf()
BIEN_occurrence_species()
BIEN_occurrence_state()
if (FALSE) { occurrence_counts<-BIEN_occurrence_records_per_species()}
Run the code above in your browser using DataLab