powered by
BIEN_phylogeny_complete downloads a specified number of the BIEN phylogeny replicates.
BIEN_phylogeny_complete(n_phylogenies = 1, seed = NULL, replicates = NULL, ...)
A phylo or multiphylo object containing the specified phylogenies
The number of phylogenies to download. Should be an integer between 1 and 100. Default is 1.
Argument passed to set.seed. Useful for replicating work with random phylogeny sets.
The specific replicated phylogenies to return. Should be a numeric vector of integers between 1 and 100.
Additional arguments passed to internal functions.
Other phylogeny functions: BIEN_phylogeny_conservative(), BIEN_phylogeny_label_nodes()
BIEN_phylogeny_conservative()
BIEN_phylogeny_label_nodes()
if (FALSE) { phylos<-BIEN_phylogeny_complete(n_phylogenies = 10,seed = 1) phylos<-BIEN_phylogeny_complete(replicates = c(1,2,99,100))}
Run the code above in your browser using DataLab