BIEN_ranges_species extracts range maps for the specified species.
BIEN_ranges_species(
species,
directory = NULL,
matched = TRUE,
match_names_only = FALSE,
include.gid = FALSE,
...
)Range maps for specified species.
A single species or a vector of species.
Directory that range maps should be saved in. If none is specified, range maps will be saved in the current working directory.
Return a list of taxa that were downloaded. Default is TRUE.
Check for range maps for the taxa specified without downloading range maps. Default is FALSE.
Should the files returned have a unique GID appended to them? This is needed if downloading multiple maps for the same species.
Additional arguments passed to internal functions.
Other range functions:
BIEN_ranges_box(),
BIEN_ranges_genus(),
BIEN_ranges_intersect_species(),
BIEN_ranges_list(),
BIEN_ranges_load_species(),
BIEN_ranges_sf(),
BIEN_ranges_shapefile_to_skinny(),
BIEN_ranges_skinny_ranges_to_richness_raster(),
BIEN_ranges_species_bulk()