powered by
BIEN_trait_species extracts trait data for the species country.
BIEN_trait_country( country, trait.name = NULL, all.taxonomy = FALSE, political.boundaries = TRUE, source.citation = FALSE, ... )
A dataframe of all available trait data for the given country.
A single country or a vector of countries.
Optional. The trait or traits you want returned. If left blank, all traits will be returned.
Should full taxonomic information and TNRS output be returned? Default is FALSE.
Should political boundary information (country, state, etc.) be returned? Default is FALSE.
Should readable source information be downloaded for each record? Note that BIEN_metadata_citation may be more useful.
BIEN_metadata_citation
Additional arguments passed to internal functions.
Other trait functions: BIEN_trait_family(), BIEN_trait_genus(), BIEN_trait_list(), BIEN_trait_mean(), BIEN_trait_species(), BIEN_trait_traitbyfamily(), BIEN_trait_traitbygenus(), BIEN_trait_traitbyspecies(), BIEN_trait_traits_per_species(), BIEN_trait_trait()
BIEN_trait_family()
BIEN_trait_genus()
BIEN_trait_list()
BIEN_trait_mean()
BIEN_trait_species()
BIEN_trait_traitbyfamily()
BIEN_trait_traitbygenus()
BIEN_trait_traitbyspecies()
BIEN_trait_traits_per_species()
BIEN_trait_trait()
if (FALSE) { BIEN_trait_country("South Africa") BIEN_trait_country(country="South Africa",trait="whole plant growth form")}
Run the code above in your browser using DataLab